#! /usr/bin/python
#--------------------------------------------------------------------
# PROGRAM    : __init__.py	
# CREATED BY : hjkim @IIS.2015-07-12 09:54:37.974795
# MODIFED BY :
#
# USAGE      : $ ./__init__.py
#
# DESCRIPTION:
#------------------------------------------------------cf0.2@20120401


import  os,sys
from    optparse        import OptionParser
from    cf.util.LOGGER  import *


@ETA
def main(args,opts):
    print args
    print opts

    return


if __name__=='__main__':
    usage   = 'usage: %prog [options] arg'
    version = '%prog 1.0'

    parser  = OptionParser(usage=usage,version=version)

#    parser.add_option('-r','--rescan',action='store_true',dest='rescan',
#                      help='rescan all directory to find missing file')

    (options,args)  = parser.parse_args()

#    if len(args) == 0:
#        parser.print_help()
#    else:
#        main(args,options)

#    LOG     = LOGGER()
    main(args,options)

    


#!/usr/bin/env python

from distutils.core import setup

setup( name                 = 'coreframe',
       version              = '0.1a',
       description          = 'COmmon REsearch FRAMEwork',
       long_description     = ''' long_description to be written. ''',
       classifiers          = [
                            'Development Status :: 4 - Beta',
                            'License :: OSI Approved :: MIT License',
                            'Programming Language :: Python :: 2.7',
                            'Topic :: Scientific/Engineering :: Atmospheric Science',
                            ],
       keywords             = '',
       url                  = 'https://github.com/hyungjun/coreframe',
       author               = 'Hyungjun Kim',
       author_email         = 'hyungjun@gmail.com',
       license              = 'MIT',

       package_dir          = {'TimeSeries':''},
       packages             = ['TimeSeries',],
      )

